Crate nvtx_sys

Crate nvtx_sys 

Modules

ffi
The unmodified FFI imported functions, types, and definitions
resource_type
Resource types for use within crate::ResourceAttributes.

Structs

DomainHandle
Unique handle for a registered domain.
ResourceHandle
Unique handle for a registered resource.
StringHandle
Unique handle for a registered string.
SyncUserHandle
Unique handle for a registered user-defined synchronization object.

Constants

NVTX_EVENT_ATTRIBUTES_SIZE
NVTX_RESOURCE_ATTRIBUTES_SIZE
NVTX_SYNC_USER_ATTRIBUTES_SIZE
NVTX_VERSION
The NVTX version.

Functions

domain_create_ascii
Create a new domain with a given ASCII string name.
domain_create_unicode
Create a new domain with a given Unicode string name.
domain_destroy
Destroy a domain.
domain_mark_ex
Create a mark within a domain.
domain_name_category_ascii
Name a category within a domain with an ASCII string.
domain_name_category_unicode
Name a category within a domain with a Unicode string.
domain_range_end
End a process-visible range within a domain.
domain_range_pop
End a thread-visible range within a domain.
domain_range_push_ex
Start a thread-visible range within a domain with an attributes structure.
domain_range_start_ex
Start a process-visible range within a domain with an attributes structure.
domain_register_string_ascii
Register an immutable ASCII string with a domain.
domain_register_string_unicode
Register an immutable Unicode string with a domain.
domain_resource_create
Create a named resource within a domain.
domain_resource_destroy
Destroy a named resource.
domain_syncuser_acquire_failed
Indicate that a user-defined synchronization acquisition failed.
domain_syncuser_acquire_releasing
Indicate that a user-defined synchronization is released.
domain_syncuser_acquire_start
Indicate that a user-defined synchronization started to acquire.
domain_syncuser_acquire_success
Indicate that a user-defined synchronization acquisition succeeded.
domain_syncuser_create
Create a new user-defined synchronization within a domain.
domain_syncuser_destroy
Destroy a user-defined synchronization.
mark_ascii
Create a mark with an ASCII string.
mark_ex
Create a mark with an attributes structure.
mark_unicode
Create a mark with a Unicode string.
name_category_ascii
Name a category with an ASCII string.
name_category_unicode
Name a category with a Unicode string.
name_os_thread_ascii
Name an OS thread with an ASCII string.
name_os_thread_unicode
Name an OS thread with a Unicode string.
range_end
End a process-visible range.
range_pop
End a thread-visible range.
range_push_ascii
Start a thread-visible range with an ASCII string.
range_push_ex
Start a thread-visible range with an attributes structure.
range_push_unicode
Start a thread-visible range with a Unicode string.
range_start_ascii
Start a process-visible range with an ASCII string.
range_start_ex
Start a process-visible range with an attributes structure.
range_start_unicode
Start a process-visible range with a Unicode string.

Type Aliases

ColorType
EventAttributes color type.
EventAttributes
Struct representing all possible Event attributes.
MessageType
EventAttributes and ResourceAttributes message type.
MessageValue
EventAttributes and ResourceAttributes message value.
PayloadType
EventAttributes payload type.
PayloadValue
EventAttributes payload value union.
RangeId
A unique range identifier.
ResourceAttributes
Struct representing all possible Resource attributes.
ResourceAttributesIdentifier
ResourceAttributes identifier union.
SyncUserAttributes
Struct representing all possible User-defined Synchronization attributes.