pub fn domain_range_push_ex(
domain: DomainHandle,
event_attrib: &EventAttributes,
) -> i32Expand description
Start a thread-visible range within a domain with an attributes structure.
To close, see domain_range_pop.
pub fn domain_range_push_ex(
domain: DomainHandle,
event_attrib: &EventAttributes,
) -> i32Start a thread-visible range within a domain with an attributes structure.
To close, see domain_range_pop.