pub fn domain_range_start_ex(
domain: DomainHandle,
event_attrib: &EventAttributes,
) -> RangeIdExpand description
Start a process-visible range within a domain with an attributes structure.
To close the range, see domain_range_end.
pub fn domain_range_start_ex(
domain: DomainHandle,
event_attrib: &EventAttributes,
) -> RangeIdStart a process-visible range within a domain with an attributes structure.
To close the range, see domain_range_end.