pub fn domain_syncuser_acquire_failed(handle: SyncUserHandle)Expand description
Indicate that a user-defined synchronization acquisition failed.
Note: this call is only valid after a call to domain_syncuser_acquire_start.
pub fn domain_syncuser_acquire_failed(handle: SyncUserHandle)Indicate that a user-defined synchronization acquisition failed.
Note: this call is only valid after a call to domain_syncuser_acquire_start.