Modules
- ffi
- The unmodified FFI imported functions, types, and definitions
- resource_
type - Resource types for use within
crate::ResourceAttributes.
Structs
- Domain
Handle - Unique handle for a registered domain.
- Resource
Handle - Unique handle for a registered resource.
- String
Handle - Unique handle for a registered string.
- Sync
User Handle - Unique handle for a registered user-defined synchronization object.
Constants
- NVTX_
EVENT_ ATTRIBUTES_ SIZE - NVTX_
RESOURCE_ ATTRIBUTES_ SIZE - NVTX_
SYNC_ USER_ ATTRIBUTES_ SIZE - NVTX_
VERSION - The NVTX version.
Functions
- domain_
create_ ascii - Create a new domain with a given ASCII string name.
- domain_
create_ unicode - Create a new domain with a given Unicode string name.
- domain_
destroy - Destroy a domain.
- domain_
mark_ ex - Create a mark within a domain.
- domain_
name_ category_ ascii - Name a category within a domain with an ASCII string.
- domain_
name_ category_ unicode - Name a category within a domain with a Unicode string.
- domain_
range_ end - End a process-visible range within a domain.
- domain_
range_ pop - End a thread-visible range within a domain.
- domain_
range_ push_ ex - Start a thread-visible range within a domain with an attributes structure.
- domain_
range_ start_ ex - Start a process-visible range within a domain with an attributes structure.
- domain_
register_ string_ ascii - Register an immutable ASCII string with a domain.
- domain_
register_ string_ unicode - Register an immutable Unicode string with a domain.
- domain_
resource_ create - Create a named resource within a domain.
- domain_
resource_ destroy - Destroy a named resource.
- domain_
syncuser_ acquire_ failed - Indicate that a user-defined synchronization acquisition failed.
- domain_
syncuser_ acquire_ releasing - Indicate that a user-defined synchronization is released.
- domain_
syncuser_ acquire_ start - Indicate that a user-defined synchronization started to acquire.
- domain_
syncuser_ acquire_ success - Indicate that a user-defined synchronization acquisition succeeded.
- domain_
syncuser_ create - Create a new user-defined synchronization within a domain.
- domain_
syncuser_ destroy - Destroy a user-defined synchronization.
- mark_
ascii - Create a mark with an ASCII string.
- mark_ex
- Create a mark with an attributes structure.
- mark_
unicode - Create a mark with a Unicode string.
- name_
category_ ascii - Name a category with an ASCII string.
- name_
category_ unicode - Name a category with a Unicode string.
- name_
os_ thread_ ascii - Name an OS thread with an ASCII string.
- name_
os_ thread_ unicode - Name an OS thread with a Unicode string.
- range_
end - End a process-visible range.
- range_
pop - End a thread-visible range.
- range_
push_ ascii - Start a thread-visible range with an ASCII string.
- range_
push_ ex - Start a thread-visible range with an attributes structure.
- range_
push_ unicode - Start a thread-visible range with a Unicode string.
- range_
start_ ascii - Start a process-visible range with an ASCII string.
- range_
start_ ex - Start a process-visible range with an attributes structure.
- range_
start_ unicode - Start a process-visible range with a Unicode string.
Type Aliases
- Color
Type EventAttributescolor type.- Event
Attributes - Struct representing all possible Event attributes.
- Message
Type EventAttributesandResourceAttributesmessage type.- Message
Value EventAttributesandResourceAttributesmessage value.- Payload
Type EventAttributespayload type.- Payload
Value EventAttributespayload value union.- RangeId
- A unique range identifier.
- Resource
Attributes - Struct representing all possible Resource attributes.
- Resource
Attributes Identifier ResourceAttributesidentifier union.- Sync
User Attributes - Struct representing all possible User-defined Synchronization attributes.